==> org.knime.base.source_2.5.2.0032292.jar: org/knime/base/node/io/database/DBReaderConnectionNodeModel.java <==
/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * -------------------------------------------------------------------
 *
 */
package org.knime.base.node.io.database;

import org.knime.core.data.DataTableSpec;
import org.knime.core.node.CanceledExecutionException;
import org.knime.core.node.ExecutionContext;
import org.knime.core.node.InvalidSettingsException;
import org.knime.core.node.NodeSettingsRO;
import org.knime.core.node.NodeSettingsWO;
import org.knime.core.node.port.PortObject;
import org.knime.core.node.port.PortObjectSpec;
import org.knime.core.node.port.PortType;
import org.knime.core.node.port.database.DatabasePortObject;
import org.knime.core.node.port.database.DatabasePortObjectSpec;
import org.knime.core.node.port.database.DatabaseQueryConnectionSettings;
import org.knime.core.node.port.database.DatabaseReaderConnection;

/**
 *
 * @author Thomas Gabriel, University of Konstanz
 */
final class DBReaderConnectionNodeModel extends DBNodeModel
        implements DBVariableSupportNodeModel {

    private final DatabaseReaderConnection m_load =
        new DatabaseReaderConnection(null);

    /**
     * Creates a new database reader.
     */
    DBReaderConnectionNodeModel() {
        super(new PortType[0], new PortType[]{DatabasePortObject.TYPE});
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void saveSettingsTo(final NodeSettingsWO settings) {
        super.saveSettingsTo(settings);
        DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
        if (conn != null) {
            conn.saveConnection(settings);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void validateSettings(final NodeSettingsRO settings)
            throws InvalidSettingsException {
        super.validateSettings(settings);
        new DatabaseQueryConnectionSettings(settings, getCredentialsProvider());
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void loadValidatedSettingsFrom(final NodeSettingsRO settings)
            throws InvalidSettingsException {
        super.loadValidatedSettingsFrom(settings);
        DatabaseQueryConnectionSettings conn =
            new DatabaseQueryConnectionSettings(settings,
                getCredentialsProvider());
        try {
            m_load.setDBQueryConnection(conn);
        } catch (Exception e) {
            throw new InvalidSettingsException(e);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected PortObject[] execute(final PortObject[] inData,
            final ExecutionContext exec)
            throws CanceledExecutionException, Exception {
        DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
        conn = new DatabaseQueryConnectionSettings(conn,
                parseQuery(conn.getQuery()));
        DatabaseReaderConnection load = new DatabaseReaderConnection(conn);
        DataTableSpec spec = load.getDataTableSpec(
                getCredentialsProvider());
        DatabasePortObject dbObj = new DatabasePortObject(
                new DatabasePortObjectSpec(spec, conn.createConnectionModel()));
        return new PortObject[]{dbObj};
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected PortObjectSpec[] configure(final PortObjectSpec[] inSpecs)
            throws InvalidSettingsException {
        try {
            // try to create database connection
            DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
            if (conn == null) {
                throw new InvalidSettingsException(
                        "No database connection available.");
            }
            conn = new DatabaseQueryConnectionSettings(conn,
                    parseQuery(conn.getQuery()));
            DatabaseReaderConnection load = new DatabaseReaderConnection(conn);
            DataTableSpec spec = load.getDataTableSpec(
                    getCredentialsProvider());
            if (spec == null) {
                throw new InvalidSettingsException(
                        "No database connection available.");
            }
            DatabasePortObjectSpec dbSpec = new DatabasePortObjectSpec(spec,
                    conn.createConnectionModel());
            return new PortObjectSpec[]{dbSpec};
        } catch (InvalidSettingsException ise) {
            throw ise;
        } catch (Throwable t) {
            throw new InvalidSettingsException(t);
        }
    }

    /**
     * Parses the given R command and replaces the variables.
     * @param rCommand the R command to parse
     * @param model delegator to to retrieve variables
     * @return the R script where the variables have been replace with
     *         their actual value
     */
    private String parseQuery(final String query) {
        String command = new String(query);
        return DBVariableSupportNodeModel.Resolver.parse(command, this);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int delegatePeekFlowVariableInt(final String name) {
        return super.peekFlowVariableInt(name);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public double delegatePeekFlowVariableDouble(final String name) {
        return peekFlowVariableDouble(name);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String delegatePeekFlowVariableString(final String name) {
        return peekFlowVariableString(name);
    }

}

==> org.knime.base.source_2.7.2.0036614.jar: org/knime/base/node/io/database/DBReaderConnectionNodeModel.java <==
/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * -------------------------------------------------------------------
 *
 */
package org.knime.base.node.io.database;

import org.knime.core.data.DataTableSpec;
import org.knime.core.node.CanceledExecutionException;
import org.knime.core.node.ExecutionContext;
import org.knime.core.node.InvalidSettingsException;
import org.knime.core.node.NodeSettingsRO;
import org.knime.core.node.NodeSettingsWO;
import org.knime.core.node.port.PortObject;
import org.knime.core.node.port.PortObjectSpec;
import org.knime.core.node.port.PortType;
import org.knime.core.node.port.database.DatabasePortObject;
import org.knime.core.node.port.database.DatabasePortObjectSpec;
import org.knime.core.node.port.database.DatabaseQueryConnectionSettings;
import org.knime.core.node.port.database.DatabaseReaderConnection;

/**
 *
 * @author Thomas Gabriel, University of Konstanz
 */
final class DBReaderConnectionNodeModel extends DBNodeModel
        implements DBVariableSupportNodeModel {

    private final DatabaseReaderConnection m_load =
        new DatabaseReaderConnection(null);

    /**
     * Creates a new database reader.
     */
    DBReaderConnectionNodeModel() {
        super(new PortType[0], new PortType[]{DatabasePortObject.TYPE});
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void saveSettingsTo(final NodeSettingsWO settings) {
        super.saveSettingsTo(settings);
        DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
        if (conn != null) {
            conn.saveConnection(settings);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void validateSettings(final NodeSettingsRO settings)
            throws InvalidSettingsException {
        super.validateSettings(settings);
        new DatabaseQueryConnectionSettings(settings, getCredentialsProvider());
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void loadValidatedSettingsFrom(final NodeSettingsRO settings)
            throws InvalidSettingsException {
        super.loadValidatedSettingsFrom(settings);
        DatabaseQueryConnectionSettings conn =
            new DatabaseQueryConnectionSettings(settings,
                getCredentialsProvider());
        try {
            m_load.setDBQueryConnection(conn);
        } catch (Exception e) {
            throw new InvalidSettingsException(e);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected PortObject[] execute(final PortObject[] inData,
            final ExecutionContext exec)
            throws CanceledExecutionException, Exception {
        DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
        conn = new DatabaseQueryConnectionSettings(conn,
                parseQuery(conn.getQuery()));
        DatabaseReaderConnection load = new DatabaseReaderConnection(conn);
        DataTableSpec spec = load.getDataTableSpec(
                getCredentialsProvider());
        DatabasePortObject dbObj = new DatabasePortObject(
                new DatabasePortObjectSpec(spec, conn.createConnectionModel()));
        return new PortObject[]{dbObj};
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected PortObjectSpec[] configure(final PortObjectSpec[] inSpecs)
            throws InvalidSettingsException {
        try {
            // try to create database connection
            DatabaseQueryConnectionSettings conn = m_load.getQueryConnection();
            if (conn == null) {
                throw new InvalidSettingsException("No database connection available.");
            }
            conn = new DatabaseQueryConnectionSettings(conn, parseQuery(conn.getQuery()));
            DatabaseReaderConnection load = new DatabaseReaderConnection(conn);
            DataTableSpec spec = load.getDataTableSpec(getCredentialsProvider());
            if (spec == null) {
                throw new InvalidSettingsException("No database connection available.");
            }
            DatabasePortObjectSpec dbSpec = new DatabasePortObjectSpec(spec, conn.createConnectionModel());
            return new PortObjectSpec[]{dbSpec};
        } catch (InvalidSettingsException ise) {
            throw ise;
        } catch (Throwable t) {
            throw new InvalidSettingsException(t);
        }
    }

    /**
     * Parses the given R command and replaces the variables.
     * @param rCommand the R command to parse
     * @param model delegator to to retrieve variables
     * @return the R script where the variables have been replace with
     *         their actual value
     */
    private String parseQuery(final String query) {
        return DBVariableSupportNodeModel.Resolver.parse(query, this);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int delegatePeekFlowVariableInt(final String name) {
        return super.peekFlowVariableInt(name);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public double delegatePeekFlowVariableDouble(final String name) {
        return peekFlowVariableDouble(name);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String delegatePeekFlowVariableString(final String name) {
        return peekFlowVariableString(name);
    }

}
